@@ -52,7 +52,7 @@ namespace BOOM {
                              UnivParams>,  // slope tail thickness
         public IID_DataPolicy<DoubleData>,
         public PriorPolicy,
-        public StateModel {
+        virtual public StateModel {
    public:
     explicit StudentLocalLinearTrendStateModel(double sigma_level = 1.0,
                                                double nu_level = 1000,
@@ -65,12 +65,7 @@ namespace BOOM {
     void observe_time_dimension(int max_time) override;
 
     void observe_state(const ConstVectorView &then, const ConstVectorView &now,
-                       int time_now, ScalarStateSpaceModelBase *model) override;
-    void observe_dynamic_intercept_regression_state(
-        const ConstVectorView &then, const ConstVectorView &now, int time_now,
-        DynamicInterceptRegressionModel *model) override {
-      observe_state(then, now, time_now, nullptr);
-    }
+                       int time_now) override;
 
     uint state_dimension() const override { return 2; }
     uint state_error_dimension() const override { return state_dimension(); }
@@ -99,13 +94,6 @@ namespace BOOM {
 
     SparseVector observation_matrix(int t) const override;
 
-    Ptr<SparseMatrixBlock>
-    dynamic_intercept_regression_observation_coefficients(
-        int t, const StateSpace::MultiplexedData &data_point) const override {
-      return new IdenticalRowsMatrix(observation_matrix(t),
-                                     data_point.total_sample_size());
-    }
-
     Vector initial_state_mean() const override;
     void set_initial_state_mean(const Vector &v);
     SpdMatrix initial_state_variance() const override;
@@ -146,7 +134,9 @@ namespace BOOM {
     const WeightedGaussianSuf &sigma_slope_complete_data_suf() const;
     const GammaSuf &nu_level_complete_data_suf() const;
     const GammaSuf &nu_slope_complete_data_suf() const;
-
+    const Vector &level_residuals() const {return level_residuals_;}
+    const Vector &slope_residuals() const {return slope_residuals_;}
+    
     // Posterior draws for the weights in the normal mixture
     // representation of the T distribution.  For Gaussian models the
     // weights will be around 1.  A large outlier has a small weight.
@@ -173,6 +163,9 @@ namespace BOOM {
     GammaSuf level_weight_sufficient_statistics_;
     GammaSuf slope_weight_sufficient_statistics_;
 
+    Vector level_residuals_;
+    Vector slope_residuals_;
+    
     StateModel::Behavior behavior_;
   };
 
