@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2006 Steven L. Scott
 
@@ -15,37 +16,35 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/Glm/PosteriorSamplers/MnpBetaSampler.hpp>
-#include <Models/MvnModel.hpp>
-#include <Models/Glm/MultinomialProbitModel.hpp>
-#include <distributions.hpp>
+#include "Models/Glm/PosteriorSamplers/MnpBetaSampler.hpp"
+#include "Models/Glm/MultinomialProbitModel.hpp"
+#include "Models/MvnModel.hpp"
+#include "distributions.hpp"
 
-namespace BOOM{
+namespace BOOM {
   typedef MnpBetaSampler MBS;
   typedef MultinomialProbitModel MNP;
-  MBS::MnpBetaSampler(MNP *Mod, Ptr<MvnModel> Pri, RNG &seeding_rng)
-    : PosteriorSampler(seeding_rng),
-      mnp(Mod),
-      pri(Pri),
-      b0_fixed(true)
-  {}
+  MBS::MnpBetaSampler(MNP *Mod, const Ptr<MvnModel> &Pri, RNG &seeding_rng)
+      : PosteriorSampler(seeding_rng), mnp(Mod), pri(Pri), b0_fixed(true) {}
 
-  void MBS::draw(){
+  void MBS::draw() {
     SpdMatrix ivar = mnp->xtx() + pri->siginv();
-    Vector mean = mnp->xty() + pri->siginv()*pri->mu();
+    Vector mean = mnp->xty() + pri->siginv() * pri->mu();
     mean = ivar.solve(mean);
     Vector beta = rmvn_ivar(mean, ivar);
-    if(b0_fixed){
+    if (b0_fixed) {
       uint start = 0;
       uint p = mnp->subject_nvars();
-      Vector b0(beta.begin(), beta.begin()+p);
-      for(uint i=0; i<mnp->Nchoices(); ++i){
+      Vector b0(beta.begin(), beta.begin() + p);
+      for (uint i = 0; i < mnp->Nchoices(); ++i) {
         VectorView(beta, start, p) -= b0;
-    start+=p;}}
+        start += p;
+      }
+    }
     mnp->set_beta(beta);
   }
 
-  double MBS::logpri()const{return pri->logp(mnp->beta());}
+  double MBS::logpri() const { return pri->logp(mnp->beta()); }
 
-  void MBS::fix_beta0(bool yn){b0_fixed = yn;}
-}
+  void MBS::fix_beta0(bool yn) { b0_fixed = yn; }
+}  // namespace BOOM
