@@ -111,7 +111,9 @@ namespace BOOM {
 
   SSM *SSM::clone() const { return new SSM(*this); }
 
-  int SSM::time_dimension() const { return dat().size(); }
+  int SSM::time_dimension() const {
+    return dat().size();
+  }
 
   double SSM::observation_variance(int t) const {
     double sigsq = observation_model_->sigsq();
@@ -188,6 +190,25 @@ namespace BOOM {
     return ans;
   }
 
+  Matrix SSM::simulate_forecast_components(
+      RNG &rng, int forecast_horizon, const Vector &final_state) {
+    ScalarStateSpaceModelBase::set_state_model_behavior(StateModel::MARGINAL);
+    Matrix ans(number_of_state_models() + 1, forecast_horizon, 0.0);
+    int t0 = time_dimension();
+    Vector state = final_state;
+    for (int t = 0; t < forecast_horizon; ++t) {
+      state = simulate_next_state(rng, state, t + t0);
+      for (int s = 0; s < number_of_state_models(); ++s) {
+        ans(s, t) = state_model(s)->observation_matrix(t + t0).dot(
+            state_component(state, s));
+      }
+      ans.col(t).back() = rnorm_mt(rng,
+                                   ans.col(t).sum(),
+                                   observation_variance(t + t0));
+    }
+    return ans;
+  }
+
   Vector SSM::one_step_holdout_prediction_errors(
       const Vector &newY, const Vector &final_state, bool standardize) const {
     Vector ans(length(newY));
@@ -206,6 +227,48 @@ namespace BOOM {
     return ans;
   }
 
+  Matrix SSM::simulate_holdout_prediction_errors(
+      int niter, int cutpoint_number, bool standardize) {
+    Matrix ans(niter, time_dimension());
+    SubMatrix training_prediction_errors(
+        ans, 0, niter - 1, 0, cutpoint_number - 1);
+    SubMatrix holdout_prediction_errors(
+        ans, 0, niter - 1, cutpoint_number, ncol(ans) - 1);
+    std::vector<Ptr<Data>> training_data(dat().begin(), dat().begin() + cutpoint_number);
+    std::vector<Ptr<StateSpace::MultiplexedDoubleData>> holdout_data(
+        dat().begin() + cutpoint_number, dat().end());
+    clear_data();
+    for (const auto &data_point : training_data) {
+      add_data(data_point);
+    }
+    Vector holdout_data_vector;
+    for (const auto &data_point : holdout_data) {
+      if (data_point->total_sample_size() != 1) {
+        report_error("Can't compute holdout prediction errors for "
+                     "multiplex data.");
+      }
+      holdout_data_vector.push_back(data_point->double_data(0).value());
+    }
+
+    sample_posterior();
+    for (int i = 0; i < niter; ++i) {
+      sample_posterior();
+      training_prediction_errors.row(i) =
+          one_step_prediction_errors(standardize);
+      holdout_prediction_errors.row(i) =
+          one_step_holdout_prediction_errors(
+              holdout_data_vector,
+              state().last_col(),
+              standardize);
+    }
+
+    // Replace the holdout data.
+    for (const auto &data_point : holdout_data) {
+      add_data(data_point);
+    }
+    return ans;
+  }
+
   void SSM::update_observation_model_complete_data_sufficient_statistics(
       int t, double observation_error_mean, double observation_error_variance) {
     observation_model()->suf()->update_expected_value(
