@@ -241,6 +241,29 @@ namespace BOOM {
     return ans;
   }
 
+  Matrix SSPM::simulate_forecast_components(RNG &rng,
+                                            const Matrix &forecast_predictors,
+                                            const Vector &exposure,
+                                            const Vector &final_state) {
+    ScalarStateSpaceModelBase::set_state_model_behavior(StateModel::MARGINAL);
+    int forecast_horizon = nrow(forecast_predictors);
+    Matrix ans(number_of_state_models() + 2, forecast_horizon, 0.0);
+    Vector state = final_state;
+    int t0 = time_dimension();
+    for (int t = 0; t < forecast_horizon; ++t) {
+      state = simulate_next_state(rng, state, t + t0);
+      for (int s = 0; s < number_of_state_models(); ++s) {
+        ans(s, t) = state_model(s)->observation_matrix(t + t0).dot(
+            state_component(state, s));
+      }
+      ans(number_of_state_models(), t) = observation_model_->predict(
+          forecast_predictors.row(t));
+      double mu = exp(sum(ans.col(t)));
+      ans.col(t).back() = rpois_mt(rng, exposure[t] * mu);
+    }
+    return ans;
+  }
+
   Vector SSPM::one_step_holdout_prediction_errors(
       RNG &rng, PoissonDataImputer &data_imputer, const Vector &counts,
       const Vector &exposure, const Matrix &predictors,
@@ -322,4 +345,49 @@ namespace BOOM {
     return ans;
   }
 
+  Matrix SSPM::simulate_holdout_prediction_errors(
+      int niter, int cutpoint_number, bool standardize) {
+    Matrix ans(niter, time_dimension());
+    SubMatrix training_prediction_errors(
+        ans, 0, niter - 1, 0, cutpoint_number - 1);
+    SubMatrix holdout_prediction_errors(
+        ans, 0, niter - 1, cutpoint_number, ncol(ans) - 1);
+    std::vector<Ptr<Data>> training_data(dat().begin(), dat().begin() + cutpoint_number);
+    std::vector<Ptr<StateSpace::AugmentedPoissonRegressionData>> holdout_data(
+        dat().begin() + cutpoint_number, dat().end());
+    clear_data();
+    for (const auto &data_point : training_data) {
+      add_data(data_point);
+    }
+    Matrix holdout_predictors(holdout_data.size(), xdim());
+    Vector holdout_counts(holdout_data.size());
+    Vector holdout_exposure(holdout_data.size());
+    for (int i = 0; i < holdout_data.size(); ++i) {
+      if (holdout_data[i]->total_sample_size() != 1) {
+        report_error("simulate_holdout_prediction_errors does "
+                     "not work with multiplex data.");
+      }
+      const PoissonRegressionData &poisson_data(holdout_data[i]->poisson_data(0));
+      holdout_counts[i] = poisson_data.y();
+      holdout_exposure[i] = poisson_data.exposure();
+      holdout_predictors.row(i) = poisson_data.x();
+    }
+
+    PoissonDataImputer imputer;
+
+    for (int i = 0; i < niter; ++i) {
+      sample_posterior();
+      training_prediction_errors.row(i) = one_step_prediction_errors(
+          standardize);
+      holdout_prediction_errors.row(i) = one_step_holdout_prediction_errors(
+          PriorPolicy::rng(),
+          imputer,
+          holdout_counts,
+          holdout_exposure,
+          holdout_predictors,
+          state().last_col());
+    }
+    return ans;
+  }
+
 }  // namespace BOOM
